@@ -38,7 +38,7 @@ def insdat():
         return d.result
 
 def pssd():
-    # Give passcode for decrypting the varable.
+    # Give passcode for decrypting the data.
     
     from tkinter import Tk, Label, Entry, E, simpledialog
 
@@ -66,11 +66,13 @@ def cmsk(data: str, varn: str, base: str):
     
     try:
         lb = len(base)
+        data = f'{data} + {base}'
         base = sum([ord(i) for i in base])
         base = base - lb if base > lb else base + lb
         nlt = ''.join([chr(ord(i) + base) for i in data]).encode('punycode')
     except Exception as e:
-        raise e
+        print(e)
+        print('Error Occured!')
     else:
         pnam = f'setx {varn} {nlt.decode()}'
         with Popen(pnam, stdout = PIPE, bufsize = 1, universal_newlines = True, text = True) as p:
@@ -85,13 +87,19 @@ def reading(data: str, base: str):
     
     try:
         lb = len(base)
+        ck = base
         base = sum([ord(i) for i in base])
         base = base - lb if base > lb else base + lb        
         nlt = ''.join([chr(ord(i) - base) for i in data.encode().decode('punycode')])
+        dck = True if nlt.rpartition(' + ')[1] and nlt.rpartition(' + ')[2] == ck else False
+        if dck:
+            del lb, ck, base, dck
+            return nlt.rpartition(' + ')[0]
+        else:
+            print("The password doesn't matched!")
     except Exception as e:
-        raise e
-    else:
-        return nlt
+        print(e)
+        print('Error Occured!')
         
 def main():
     # CLI mode.
